@@ -1,8 +1,9 @@
 use ruff_macros::{ViolationMetadata, derive_message_formats};
-use ruff_python_ast::helpers::contains_effect;
+use ruff_python_ast::helpers::{contains_effect, is_empty_f_string};
 use ruff_python_ast::{self as ast, Expr};
 use ruff_python_codegen::Generator;
 use ruff_python_semantic::SemanticModel;
+use ruff_python_trivia::CommentRanges;
 use ruff_text_size::Ranged;
 
 use crate::checkers::ast::Checker;
@@ -31,13 +32,14 @@ use crate::{Applicability, Edit, Fix, FixAvailability, Violation};
 /// ```
 ///
 /// ## Fix safety
-/// This fix is marked as unsafe if it removes an unused `sep` keyword argument
+/// This fix is marked as unsafe if it removes comments or an unused `sep` keyword argument
 /// that may have side effects. Removing such arguments may change the program's
 /// behavior by skipping the execution of those side effects.
 ///
 /// ## References
 /// - [Python documentation: `print`](https://docs.python.org/3/library/functions.html#print)
 #[derive(ViolationMetadata)]
+#[violation_metadata(stable_since = "0.5.0")]
 pub(crate) struct PrintEmptyString {
     reason: Reason,
 }
@@ -98,6 +100,7 @@ pub(crate) fn print_empty_string(checker: &Checker, call: &ast::ExprCall) {
                     Separator::Remove,
                     checker.semantic(),
                     checker.generator(),
+                    checker.comment_ranges(),
                 )
                 .into_fix(),
             );
@@ -124,6 +127,7 @@ pub(crate) fn print_empty_string(checker: &Checker, call: &ast::ExprCall) {
                         Separator::Remove,
                         checker.semantic(),
                         checker.generator(),
+                        checker.comment_ranges(),
                     )
                     .into_fix(),
                 );
@@ -184,8 +188,14 @@ pub(crate) fn print_empty_string(checker: &Checker, call: &ast::ExprCall) {
             );
 
             diagnostic.set_fix(
-                EmptyStringFix::from_call(call, separator, checker.semantic(), checker.generator())
-                    .into_fix(),
+                EmptyStringFix::from_call(
+                    call,
+                    separator,
+                    checker.semantic(),
+                    checker.generator(),
+                    checker.comment_ranges(),
+                )
+                .into_fix(),
             );
         }
     }
@@ -193,13 +203,11 @@ pub(crate) fn print_empty_string(checker: &Checker, call: &ast::ExprCall) {
 
 /// Check if an expression is a constant empty string.
 fn is_empty_string(expr: &Expr) -> bool {
-    matches!(
-        expr,
-        Expr::StringLiteral(ast::ExprStringLiteral {
-            value,
-            ..
-        }) if value.is_empty()
-    )
+    match expr {
+        Expr::StringLiteral(ast::ExprStringLiteral { value, .. }) => value.is_empty(),
+        Expr::FString(f_string) => is_empty_f_string(f_string),
+        _ => false,
+    }
 }
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq)]
@@ -219,11 +227,16 @@ impl EmptyStringFix {
         separator: Separator,
         semantic: &SemanticModel,
         generator: Generator,
+        comment_ranges: &CommentRanges,
     ) -> Self {
         let range = call.range();
         let mut call = call.clone();
         let mut applicability = Applicability::Safe;
 
+        if comment_ranges.intersects(range) {
+            applicability = Applicability::Unsafe;
+        }
+
         // Remove all empty string positional arguments.
         call.arguments.args = call
             .arguments
