@@ -80,7 +80,7 @@ impl CallableParams {
             CallableParams::List(params) => Parameters::new(
                 db,
                 params.into_iter().map(|param| {
-                    let mut parameter = match param.kind {
+                    let parameter = match param.kind {
                         ParamKind::PositionalOnly => Parameter::positional_only(param.name),
                         ParamKind::PositionalOrKeyword => {
                             Parameter::positional_or_keyword(param.name.unwrap())
@@ -91,11 +91,9 @@ impl CallableParams {
                             Parameter::keyword_variadic(param.name.unwrap())
                         }
                     };
-                    parameter = parameter.with_annotated_type(param.annotated_ty.into_type(db));
-                    if let Some(default_ty) = param.default_ty {
-                        parameter = parameter.with_default_type(default_ty.into_type(db));
-                    }
                     parameter
+                        .with_annotated_type(param.annotated_ty.into_type(db))
+                        .with_optional_default_type(param.default_ty.map(|t| t.into_type(db)))
                 }),
             ),
         }
